aboutsummaryrefslogtreecommitdiff
path: root/mod/thewire/actions/delete.php
diff options
context:
space:
mode:
Diffstat (limited to 'mod/thewire/actions/delete.php')
-rw-r--r--mod/thewire/actions/delete.php73
1 files changed, 39 insertions, 34 deletions
diff --git a/mod/thewire/actions/delete.php b/mod/thewire/actions/delete.php
index 849433e0f..7758b4b03 100644
--- a/mod/thewire/actions/delete.php
+++ b/mod/thewire/actions/delete.php
@@ -1,34 +1,39 @@
-<?php
-
- /**
- * Elgg thewire: delete note action
- *
- * @package ElggTheWire
- */
-
- // Make sure we're logged in (send us to the front page if not)
- if (!elgg_is_logged_in()) forward();
-
- // Get input data
- $guid = (int) get_input('thewirepost');
-
- // Make sure we actually have permission to edit
- $thewire = get_entity($guid);
- if ($thewire->getSubtype() == "thewire" && $thewire->canEdit()) {
-
- // Get owning user
- $owner = $thewire->getOwnerEntity();
- // Delete it!
- $rowsaffected = $thewire->delete();
- if ($rowsaffected > 0) {
- // Success message
- system_message(elgg_echo("thewire:deleted"));
- } else {
- register_error(elgg_echo("thewire:notdeleted"));
- }
- // Forward to the main wire page
- forward("mod/thewire/?username=" . $owner->username);
-
- }
-
-?> \ No newline at end of file
+<?php
+/**
+ * Action for deleting a wire post
+ *
+ */
+
+// Get input data
+$guid = (int) get_input('guid');
+
+// Make sure we actually have permission to edit
+$thewire = get_entity($guid);
+if ($thewire->getSubtype() == "thewire" && $thewire->canEdit()) {
+
+ // unset reply metadata on children
+ $children = elgg_get_entities_from_relationship(array(
+ 'relationship' => 'parent',
+ 'relationship_guid' => $post_guid,
+ 'inverse_relationship' => true,
+ ));
+ if ($children) {
+ foreach ($children as $child) {
+ $child->reply = false;
+ }
+ }
+
+ // Get owning user
+ $owner = get_entity($thewire->getOwner());
+
+ // Delete it
+ $rowsaffected = $thewire->delete();
+ if ($rowsaffected > 0) {
+ // Success message
+ system_message(elgg_echo("thewire:deleted"));
+ } else {
+ register_error(elgg_echo("thewire:notdeleted"));
+ }
+
+ forward("pg/thewire/owner/" . $owner->username);
+}